==> jc-1.4.0.tar.gz: soot/coffi/FutureStmt.h <==
// class soot.coffi.FutureStmt

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 522aea39aed5c358 soot_coffi_FutureStmt
// @dep_class b3c0d2cd30f6acdd soot_jimple_internal_AbstractStmt
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_jimple_internal_AbstractStmt

#include "soot/jimple/internal/AbstractStmt.h"

#ifndef _JC_soot_coffi_FutureStmt_H_
#define _JC_soot_coffi_FutureStmt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_coffi_FutureStmt$sub_refs	_jc_soot_coffi_FutureStmt$sub_refs;
typedef struct _jc_soot_coffi_FutureStmt$sub_nonrefs	_jc_soot_coffi_FutureStmt$sub_nonrefs;
typedef struct _jc_soot_coffi_FutureStmt$refs	_jc_soot_coffi_FutureStmt$refs;
typedef struct _jc_soot_coffi_FutureStmt$nonrefs	_jc_soot_coffi_FutureStmt$nonrefs;
typedef struct _jc_soot_coffi_FutureStmt$object	_jc_soot_coffi_FutureStmt$object;

typedef const struct _jc_soot_coffi_FutureStmt$vmethods	_jc_soot_coffi_FutureStmt$vmethods;
typedef const struct _jc_soot_coffi_FutureStmt$vtable	_jc_soot_coffi_FutureStmt$vtable;
typedef const struct _jc_soot_coffi_FutureStmt$vtype	_jc_soot_coffi_FutureStmt$vtype;

// Constructors
extern void _jc_soot_coffi_FutureStmt$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *);
extern void _jc_soot_coffi_FutureStmt$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern void _jc_soot_coffi_FutureStmt$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *, struct _jc_object *);
extern jboolean _jc_soot_coffi_FutureStmt$method$branches$b1fa209d4c0e0b15(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_coffi_FutureStmt$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *);
extern jboolean _jc_soot_coffi_FutureStmt$method$fallsThrough$09e8b0d6b0c9d1bf(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *);
extern struct _jc_object *_jc_soot_coffi_FutureStmt$method$getDefBoxes$09ed871867d10b27(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *);
extern struct _jc_object *_jc_soot_coffi_FutureStmt$method$getUnitBoxes$63a3cb25489f231d(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *);
extern struct _jc_object *_jc_soot_coffi_FutureStmt$method$getUseBoxes$8c22fb3c6dc4d01e(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *);
extern struct _jc_java_lang_String$object *_jc_soot_coffi_FutureStmt$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *);
extern void _jc_soot_coffi_FutureStmt$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_FutureStmt$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_coffi_FutureStmt$method_info$branches$b1fa209d4c0e0b15;
extern _jc_method _jc_soot_coffi_FutureStmt$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_coffi_FutureStmt$method_info$fallsThrough$09e8b0d6b0c9d1bf;
extern _jc_method _jc_soot_coffi_FutureStmt$method_info$getDefBoxes$09ed871867d10b27;
extern _jc_method _jc_soot_coffi_FutureStmt$method_info$getUnitBoxes$63a3cb25489f231d;
extern _jc_method _jc_soot_coffi_FutureStmt$method_info$getUseBoxes$8c22fb3c6dc4d01e;
extern _jc_method _jc_soot_coffi_FutureStmt$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_coffi_FutureStmt$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_coffi_FutureStmt$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *, struct _jc_object *);
	jboolean	(*branches$b1fa209d4c0e0b15)(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *);
	jboolean	(*fallsThrough$09e8b0d6b0c9d1bf)(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *);
	struct _jc_object	*(*getDefBoxes$09ed871867d10b27)(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *);
	struct _jc_object	*(*getUnitBoxes$63a3cb25489f231d)(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *);
	struct _jc_object	*(*getUseBoxes$8c22fb3c6dc4d01e)(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *);
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_coffi_FutureStmt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_jimple_internal_AbstractStmt$vmethods	soot_jimple_internal_AbstractStmt;
	_jc_soot_coffi_FutureStmt$vmethods	soot_coffi_FutureStmt;
};

// Vtype
struct _jc_soot_coffi_FutureStmt$vtype {
	_jc_type			type;
	_jc_soot_coffi_FutureStmt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_FutureStmt$sub_refs {
	struct _jc_java_lang_Object$object	*object;
	struct _jc_object	*myEmptyList;
};

// Reference instance fields (object)
struct _jc_soot_coffi_FutureStmt$refs {
    _jc_soot_coffi_FutureStmt$sub_refs	soot_coffi_FutureStmt;
    _jc_soot_jimple_internal_AbstractStmt$sub_refs	soot_jimple_internal_AbstractStmt;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_FutureStmt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_FutureStmt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_jimple_internal_AbstractStmt$sub_nonrefs	soot_jimple_internal_AbstractStmt;
    _jc_soot_coffi_FutureStmt$sub_nonrefs	soot_coffi_FutureStmt;
};

// Object instance structure
struct _jc_soot_coffi_FutureStmt$object {
	_jc_soot_coffi_FutureStmt$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_FutureStmt$vtype	*vtype;
	_jc_soot_coffi_FutureStmt$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_FutureStmt$vtype _jc_soot_coffi_FutureStmt$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_FutureStmt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_FutureStmt$class_object;

#endif	/* _JC_soot_coffi_FutureStmt_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/FutureStmt.h <==
// class soot.coffi.FutureStmt

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 522aea39aed5c358 soot_coffi_FutureStmt
// @dep_class b3c0d2cd30f6acdd soot_jimple_internal_AbstractStmt
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_jimple_internal_AbstractStmt

#include "soot/jimple/internal/AbstractStmt.h"

#ifndef _JC_soot_coffi_FutureStmt_H_
#define _JC_soot_coffi_FutureStmt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_coffi_FutureStmt$sub_refs	_jc_soot_coffi_FutureStmt$sub_refs;
typedef struct _jc_soot_coffi_FutureStmt$sub_nonrefs	_jc_soot_coffi_FutureStmt$sub_nonrefs;
typedef struct _jc_soot_coffi_FutureStmt$refs	_jc_soot_coffi_FutureStmt$refs;
typedef struct _jc_soot_coffi_FutureStmt$nonrefs	_jc_soot_coffi_FutureStmt$nonrefs;
typedef struct _jc_soot_coffi_FutureStmt$object	_jc_soot_coffi_FutureStmt$object;

typedef const struct _jc_soot_coffi_FutureStmt$vmethods	_jc_soot_coffi_FutureStmt$vmethods;
typedef const struct _jc_soot_coffi_FutureStmt$vtable	_jc_soot_coffi_FutureStmt$vtable;
typedef const struct _jc_soot_coffi_FutureStmt$vtype	_jc_soot_coffi_FutureStmt$vtype;

// Constructors
extern void _jc_soot_coffi_FutureStmt$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *) _JC_JCNI_ATTR;
extern void _jc_soot_coffi_FutureStmt$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_coffi_FutureStmt$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_coffi_FutureStmt$method$branches$b1fa209d4c0e0b15(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_coffi_FutureStmt$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_coffi_FutureStmt$method$fallsThrough$09e8b0d6b0c9d1bf(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_coffi_FutureStmt$method$getDefBoxes$09ed871867d10b27(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_coffi_FutureStmt$method$getUnitBoxes$63a3cb25489f231d(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_coffi_FutureStmt$method$getUseBoxes$8c22fb3c6dc4d01e(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_coffi_FutureStmt$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *) _JC_JCNI_ATTR;
extern void _jc_soot_coffi_FutureStmt$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_FutureStmt$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_coffi_FutureStmt$method_info$branches$b1fa209d4c0e0b15;
extern _jc_method _jc_soot_coffi_FutureStmt$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_coffi_FutureStmt$method_info$fallsThrough$09e8b0d6b0c9d1bf;
extern _jc_method _jc_soot_coffi_FutureStmt$method_info$getDefBoxes$09ed871867d10b27;
extern _jc_method _jc_soot_coffi_FutureStmt$method_info$getUnitBoxes$63a3cb25489f231d;
extern _jc_method _jc_soot_coffi_FutureStmt$method_info$getUseBoxes$8c22fb3c6dc4d01e;
extern _jc_method _jc_soot_coffi_FutureStmt$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_coffi_FutureStmt$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_coffi_FutureStmt$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*branches$b1fa209d4c0e0b15)(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *) _JC_JCNI_ATTR;
	jboolean	(*fallsThrough$09e8b0d6b0c9d1bf)(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getDefBoxes$09ed871867d10b27)(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getUnitBoxes$63a3cb25489f231d)(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getUseBoxes$8c22fb3c6dc4d01e)(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *) _JC_JCNI_ATTR;
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_coffi_FutureStmt$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_coffi_FutureStmt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_jimple_internal_AbstractStmt$vmethods	soot_jimple_internal_AbstractStmt;
	_jc_soot_coffi_FutureStmt$vmethods	soot_coffi_FutureStmt;
};

// Vtype
struct _jc_soot_coffi_FutureStmt$vtype {
	_jc_type			type;
	_jc_soot_coffi_FutureStmt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_FutureStmt$sub_refs {
	struct _jc_java_lang_Object$object	*object;
	struct _jc_object	*myEmptyList;
};

// Reference instance fields (object)
struct _jc_soot_coffi_FutureStmt$refs {
    _jc_soot_coffi_FutureStmt$sub_refs	soot_coffi_FutureStmt;
    _jc_soot_jimple_internal_AbstractStmt$sub_refs	soot_jimple_internal_AbstractStmt;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_FutureStmt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_FutureStmt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_jimple_internal_AbstractStmt$sub_nonrefs	soot_jimple_internal_AbstractStmt;
    _jc_soot_coffi_FutureStmt$sub_nonrefs	soot_coffi_FutureStmt;
};

// Object instance structure
struct _jc_soot_coffi_FutureStmt$object {
	_jc_soot_coffi_FutureStmt$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_FutureStmt$vtype	*vtype;
	_jc_soot_coffi_FutureStmt$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_FutureStmt$vtype _jc_soot_coffi_FutureStmt$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_FutureStmt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_FutureStmt$class_object;

#endif	/* _JC_soot_coffi_FutureStmt_H_ */
